@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkOpenGLGPUVolumeRayCastMapper extends vtkGPUVolumeRayCastMapper
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -39,6 +39,14 @@ public class vtkOpenGLGPUVolumeRayCastMapper extends vtkGPUVolumeRayCastMapper
   public void SetNoiseTextureSize(int id0[])
     { SetNoiseTextureSize_7(id0); }
 
+  private native void SetPartitions_8(int id0,int id1,int id2);
+  public void SetPartitions(int id0,int id1,int id2)
+    { SetPartitions_8(id0,id1,id2); }
+
+  private native boolean PreLoadData_9(vtkRenderer id0,vtkVolume id1);
+  public boolean PreLoadData(vtkRenderer id0,vtkVolume id1)
+    { return PreLoadData_9(id0,id1); }
+
   public vtkOpenGLGPUVolumeRayCastMapper() { super(); }
 
   public vtkOpenGLGPUVolumeRayCastMapper(long id) { super(id); }
