@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkPath extends vtkPointSet
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -95,6 +95,14 @@ public class vtkPath extends vtkPointSet
     return (vtkPath)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
+  private native long GetCell_18(int id0,int id1,int id2);
+  public vtkCell GetCell(int id0,int id1,int id2) {
+    long temp = GetCell_18(id0,id1,id2);
+
+    if (temp == 0) return null;
+    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkPath() { super(); }
 
   public vtkPath(long id) { super(id); }
